/* This date time is from the last non-merge commit to Hamlib. */
#define HAMLIBDATETIME "2025-06-10T00:52:44Z SHA=371db9"
